# LLM Inputs

```{eval-rst}
.. autodata:: vllm.inputs.PromptType
```

```{eval-rst}
.. autoclass:: vllm.inputs.TextPrompt
    :show-inheritance:
    :members:
    :member-order: bysource
```

```{eval-rst}
.. autoclass:: vllm.inputs.TokensPrompt
    :show-inheritance:
    :members:
    :member-order: bysource
```
